<?php
/*
Plugin Name: Woo Account Downloadable Click&Copy (EasyToolsWP)
Description: Adds click-to-copy functionality for downloadable files on account pages.
Version: 1.0
Author: EasyToolsWP.com
*/

// Ensure the file cannot be accessed directly
if (!defined('ABSPATH')) {
    exit; // Prevent direct access
}

// Enqueue CSS and JavaScript for front-end
function etwp_enqueue_scripts() {
    if (is_account_page()) {
        wp_enqueue_style('etwp-styles', plugins_url('account-download-clickcopy.css', __FILE__));
    }
}
add_action('wp_enqueue_scripts', 'etwp_enqueue_scripts');

// Add JavaScript for copying download link
function etwp_copy_download_link_script() {
    ?>
    <script>
    jQuery(document).ready(function($) {
        function copyDownloadLink(element) {
            var downloadLink = $(element).attr('href');
            var tempInput = document.createElement("input");
            tempInput.value = downloadLink;
            document.body.appendChild(tempInput);
            tempInput.select();
            document.execCommand("copy");
            document.body.removeChild(tempInput);

            // Show the notification box for 2 seconds
            var copyNotice = document.getElementById('etwp-copy-notice');
            if (copyNotice) {
                copyNotice.style.display = 'block';
                setTimeout(function() {
                    copyNotice.style.display = 'none';
                }, 2000);
            }
        }

        $(document).on('click', '.woocommerce-MyAccount-downloads-file.button.alt', function(e) {
            e.preventDefault();
            var disableOnClick = <?php echo json_encode(get_option('etwp_button_settings')['disable_on_click']); ?>;
            
            if (!disableOnClick) {
                copyDownloadLink(this);
            } else {
                // Handle behavior when download click is disabled (if needed)
            }
        });
    });
    </script>
    <?php
}
add_action('wp_footer', 'etwp_copy_download_link_script');

// Add admin menu
add_action('admin_menu', 'etwp_plugin_settings_menu');

function etwp_plugin_settings_menu() {
    add_submenu_page(
        '',                  // Parent slug (menu slug for 'EasyToolsWP')
        'EasyToolsWP Settings',         // Page title
        'Settings',                     // Menu title
        'manage_options',               // Capability
        'easytoolswp_pro-settings',     // Menu slug
        'etwp_plugin_settings_page'     // Callback function
    );
}

// Callback function for settings page
function etwp_plugin_settings_page() {
    ?>
    <div class="wrap">
        <h1>EasyToolsWP Settings</h1>
        <form method="post" action="options.php">
            <?php
            settings_fields('etwp_settings_group');
            do_settings_sections('easytoolswp-settings');
            submit_button();
            ?>
        </form>
    </div>
    <?php
}

// Register settings
add_action('admin_init', 'etwp_register_settings');

function etwp_register_settings() {
    // Register section for popup styling
    add_settings_section(
        'etwp_styling_section',            // Section ID
        'Popup Styling',                   // Section title
        'etwp_styling_section_callback',   // Callback function to display section
        'easytoolswp-settings'            // Page where section should be displayed
    );

    // Register section for download button settings
    add_settings_section(
        'etwp_button_section',             // Section ID
        'Download Button Settings',        // Section title
        'etwp_button_section_callback',    // Callback function to display section
        'easytoolswp-settings'            // Page where section should be displayed
    );

    // Register settings and add fields
    register_setting(
        'etwp_settings_group',             // Settings group name
        'etwp_popup_styling',              // Setting for popup styling
        'sanitize_text_field'              // Sanitizer function
    );

    register_setting(
        'etwp_settings_group',             // Settings group name
        'etwp_button_settings',            // Setting for button settings
        'etwp_sanitize_button_settings'    // Sanitizer function
    );

    // Add fields to popup styling section
    add_settings_field(
        'etwp_popup_background_color',     // Field ID
        'Background Color',                // Field label
        'etwp_popup_background_color_field_callback', // Callback function to display field
        'easytoolswp-settings',           // Page where field should be displayed
        'etwp_styling_section'            // Section ID where field should be added
    );

    add_settings_field(
        'etwp_popup_text_color',
        'Text Color',
        'etwp_popup_text_color_field_callback',
        'easytoolswp-settings',
        'etwp_styling_section'
    );

    // Add fields to download button settings section
    add_settings_field(
        'etwp_disable_download_on_click',
        'Disable Download on Click',
        'etwp_disable_download_on_click_field_callback',
        'easytoolswp-settings',
        'etwp_button_section'
    );
}

// Callback functions to display settings fields

function etwp_styling_section_callback() {
    echo '<p>Settings for styling the popup.</p>';
}

function etwp_popup_background_color_field_callback() {
    $popup_background_color = get_option('etwp_popup_styling');
    echo '<input type="text" name="etwp_popup_styling[background_color]" value="' . esc_attr($popup_background_color['background_color']) . '" />';
}

function etwp_popup_text_color_field_callback() {
    $popup_text_color = get_option('etwp_popup_styling');
    echo '<input type="text" name="etwp_popup_styling[text_color]" value="' . esc_attr($popup_text_color['text_color']) . '" />';
}

function etwp_disable_download_on_click_field_callback() {
    $disable_download_on_click = get_option('etwp_button_settings');
    echo '<label><input type="checkbox" name="etwp_button_settings[disable_on_click]" value="1" ' . checked(1, $disable_download_on_click['disable_on_click'], false) . ' /> Disable download on click</label>';
}

// Sanitizer functions

function etwp_sanitize_button_settings($input) {
    $output['disable_on_click'] = (isset($input['disable_on_click']) && $input['disable_on_click'] == 1) ? 1 : 0;
    return $output;
}
?>
